==> 1.8.9.tar.gz: lib/XGeneralDecoration/XDecorations.dart <==
part of xgeneraldecoration;

class XDecoration {
  /////////// B A S E   D E C O R A T I O N S //////////

  /// BoxDecoration con border.all e di spessore 1 di colore se nullo bianco
  static boxBorderAll({Color? color}) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1));
  }

  static onlyBorder({Color? colorBackGround, Color colorBorder = Colors.greenAccent, double widthBorder = 2}) {
    return BoxDecoration(
        borderRadius: BorderRadius.all(Radius.circular(5)),
        color: colorBackGround ?? Colors.grey[850],
        border: Border.all(
          color: colorBorder,
          width: widthBorder,
        ));
  }

  static circularBox({Color? color, double? borderRadius}) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// BoxDecoration con border.bottom e di spessore 1 di colore se nullo bianco
  static boxEntryBorderBottom({Color? color}) {
    return BoxDecoration(border: Border(bottom: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// BoxDecoration con border.start e di spessore 1 di colore se nullo bianco
  static box_CellBorderStart({Color? color}) {
    return BoxDecoration(border: BorderDirectional(start: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// GREEN
  static gradientBox_GreenAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]));
  }

  static circularBox_Gradient_GreenAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  static gradientBox_GreenLightAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]));
  }

  static circularBox_Gradient_GreenLightAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  static circularBox_Gradient_GreenLight({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.green[300]!, Colors.green[400]!, Colors.green[500]!]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// ORANGE

  static gradientBox_OrangeAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]));
  }

  static circularBox_Gradient_OrangeAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// YELLOW

  static gradientBox_Yellow() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]));
  }

  static circularBox_Gradient_Yellow({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// TEAL

  static gradientBox_Teal() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]));
  }

  static circularBox_Gradient_Teal({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// GREY

  static gradientBox_Grey() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]));
  }

  static circularBox_Gradient_Grey({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// RED

  static gradientBox_RedAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]));
  }

  static circularBox_Gradient_RedAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// BLUE

  static gradientBox_Blue() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]));
  }

  static circularBox_Gradient_Blue({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]), border: Border.all(color: Colors.white, width: 1), borderRadius: BorderRadius.circular(borderRadius ?? 8));
  }

  ///  LIGHT BLUE

  static gradientBox_LightBlue() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFBBDEFB), Color(0xFF90CAF9), Color(0xFF64B5F6)]));
  }

  static circularBox_Gradient_LightBlue({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFBBDEFB), Color(0xFF90CAF9), Color(0xFF64B5F6)]), border: Border.all(color: Colors.white, width: 1), borderRadius: BorderRadius.circular(borderRadius ?? 8));
  }

  /// PURPLE

  static gradientBox_Purple() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]));
  }

  static circularBox_Gradient_Purple({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }
}

==> 11.3.0.tar.gz: lib/XGeneralDecoration/XDecorations.dart <==
part of xgeneraldecoration;

class XDecoration {
  /////////// B A S E   D E C O R A T I O N S //////////

  /// BoxDecoration con border.all e di spessore 1 di colore se nullo bianco
  static boxBorderAll({Color? color}) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1));
  }

  static onlyBorder({Color? colorBackGround, Color colorBorder = Colors.greenAccent, double widthBorder = 2, double borderRadius = 5}) {
    return BoxDecoration(
        borderRadius: BorderRadius.all(Radius.circular(borderRadius)),
        color: colorBackGround ?? Colors.grey[850],
        border: Border.all(
          color: colorBorder,
          width: widthBorder,
        ));
  }

  static circularBox({Color? color, double? borderRadius}) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// BoxDecoration con border.bottom e di spessore 1 di colore se nullo bianco
  static boxEntryBorderBottom({Color? color}) {
    return BoxDecoration(border: Border(bottom: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// BoxDecoration con border.start e di spessore 1 di colore se nullo bianco
  static box_CellBorderStart({Color? color}) {
    return BoxDecoration(border: BorderDirectional(start: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// GREEN
  static gradientBox_GreenAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]));
  }

  static circularBox_Gradient_GreenAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  static gradientBox_GreenLightAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]));
  }

  static circularBox_Gradient_GreenLightAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  static circularBox_Gradient_GreenLight({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.green[300]!, Colors.green[400]!, Colors.green[500]!]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// ORANGE

  static gradientBox_OrangeAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]));
  }

  static circularBox_Gradient_OrangeAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// YELLOW

  static gradientBox_Yellow() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]));
  }

  static circularBox_Gradient_Yellow({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// TEAL

  static gradientBox_Teal() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]));
  }

  static circularBox_Gradient_Teal({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// GREY

  static gradientBox_Grey() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]));
  }

  static circularBox_Gradient_Grey({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// RED

  static gradientBox_RedAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]));
  }

  static circularBox_Gradient_RedAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// BLUE

  static gradientBox_Blue() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]));
  }

  static circularBox_Gradient_Blue({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]), border: Border.all(color: Colors.white, width: 1), borderRadius: BorderRadius.circular(borderRadius ?? 8));
  }

  ///  LIGHT BLUE

  static gradientBox_LightBlue() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFBBDEFB), Color(0xFF90CAF9), Color(0xFF64B5F6)]));
  }

  static circularBox_Gradient_LightBlue({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFBBDEFB), Color(0xFF90CAF9), Color(0xFF64B5F6)]), border: Border.all(color: Colors.white, width: 1), borderRadius: BorderRadius.circular(borderRadius ?? 8));
  }

  /// PURPLE

  static gradientBox_Purple() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]));
  }

  static circularBox_Gradient_Purple({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }
}
